@@ -1348,8 +1348,8 @@ PatchBaselineIdentityTypeDef = TypedDict(
     total=False,
 )
 
-PatchComplianceDataTypeDef = TypedDict(
-    "PatchComplianceDataTypeDef",
+_RequiredPatchComplianceDataTypeDef = TypedDict(
+    "_RequiredPatchComplianceDataTypeDef",
     {
         "Title": str,
         "KBId": str,
@@ -1367,6 +1367,16 @@ PatchComplianceDataTypeDef = TypedDict(
         "InstalledTime": datetime,
     },
 )
+_OptionalPatchComplianceDataTypeDef = TypedDict(
+    "_OptionalPatchComplianceDataTypeDef", {"CVEIds": str}, total=False
+)
+
+
+class PatchComplianceDataTypeDef(
+    _RequiredPatchComplianceDataTypeDef, _OptionalPatchComplianceDataTypeDef
+):
+    pass
+
 
 PatchFilterGroupTypeDef = TypedDict(
     "PatchFilterGroupTypeDef", {"PatchFilters": List["PatchFilterTypeDef"]}
